# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mainwindow.ui'
#
# Created by: PyQt5 UI code generator 5.7
#
# WARNING! All changes made in this file will be lost!

from PyQt5 import QtCore, QtGui, QtWidgets

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName("MainWindow")
        MainWindow.resize(496, 743)
        self.centralwidget = QtWidgets.QWidget(MainWindow)
        self.centralwidget.setObjectName("centralwidget")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setObjectName("verticalLayout")
        self.inputGroupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.inputGroupBox.setObjectName("inputGroupBox")
        self.gridLayout = QtWidgets.QGridLayout(self.inputGroupBox)
        self.gridLayout.setObjectName("gridLayout")
        self.fileRadioButton = QtWidgets.QRadioButton(self.inputGroupBox)
        self.fileRadioButton.setObjectName("fileRadioButton")
        self.gridLayout.addWidget(self.fileRadioButton, 0, 0, 1, 1)
        self.directoryRadioButton = QtWidgets.QRadioButton(self.inputGroupBox)
        self.directoryRadioButton.setObjectName("directoryRadioButton")
        self.gridLayout.addWidget(self.directoryRadioButton, 0, 1, 1, 1)
        self.inputEdit = QtWidgets.QLineEdit(self.inputGroupBox)
        self.inputEdit.setText("")
        self.inputEdit.setReadOnly(True)
        self.inputEdit.setObjectName("inputEdit")
        self.gridLayout.addWidget(self.inputEdit, 1, 0, 1, 2)
        self.browseButton = QtWidgets.QPushButton(self.inputGroupBox)
        self.browseButton.setObjectName("browseButton")
        self.gridLayout.addWidget(self.browseButton, 1, 2, 1, 1)
        self.batchModeCheckBox = QtWidgets.QCheckBox(self.inputGroupBox)
        self.batchModeCheckBox.setObjectName("batchModeCheckBox")
        self.gridLayout.addWidget(self.batchModeCheckBox, 2, 0, 1, 1)
        self.verticalLayout.addWidget(self.inputGroupBox)
        self.seedingGroupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.seedingGroupBox.setObjectName("seedingGroupBox")
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(self.seedingGroupBox)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.trackerLabel = QtWidgets.QLabel(self.seedingGroupBox)
        self.trackerLabel.setObjectName("trackerLabel")
        self.verticalLayout_2.addWidget(self.trackerLabel)
        self.trackerEdit = QtWidgets.QPlainTextEdit(self.seedingGroupBox)
        self.trackerEdit.setObjectName("trackerEdit")
        self.verticalLayout_2.addWidget(self.trackerEdit)
        self.webSeedLabel = QtWidgets.QLabel(self.seedingGroupBox)
        self.webSeedLabel.setObjectName("webSeedLabel")
        self.verticalLayout_2.addWidget(self.webSeedLabel)
        self.webSeedEdit = QtWidgets.QPlainTextEdit(self.seedingGroupBox)
        self.webSeedEdit.setObjectName("webSeedEdit")
        self.verticalLayout_2.addWidget(self.webSeedEdit)
        self.verticalLayout.addWidget(self.seedingGroupBox)
        self.optionGroupBox = QtWidgets.QGroupBox(self.centralwidget)
        self.optionGroupBox.setObjectName("optionGroupBox")
        self.gridLayout_2 = QtWidgets.QGridLayout(self.optionGroupBox)
        self.gridLayout_2.setObjectName("gridLayout_2")
        self.pieceCountLabel = QtWidgets.QLabel(self.optionGroupBox)
        self.pieceCountLabel.setObjectName("pieceCountLabel")
        self.gridLayout_2.addWidget(self.pieceCountLabel, 3, 1, 1, 1)
        self.pieceSizeComboBox = QtWidgets.QComboBox(self.optionGroupBox)
        self.pieceSizeComboBox.setMaximumSize(QtCore.QSize(100, 16777215))
        self.pieceSizeComboBox.setObjectName("pieceSizeComboBox")
        self.gridLayout_2.addWidget(self.pieceSizeComboBox, 3, 0, 1, 1)
        self.md5CheckBox = QtWidgets.QCheckBox(self.optionGroupBox)
        self.md5CheckBox.setObjectName("md5CheckBox")
        self.gridLayout_2.addWidget(self.md5CheckBox, 7, 0, 1, 2)
        self.pieceSizeLabel = QtWidgets.QLabel(self.optionGroupBox)
        self.pieceSizeLabel.setObjectName("pieceSizeLabel")
        self.gridLayout_2.addWidget(self.pieceSizeLabel, 2, 0, 1, 1)
        self.privateTorrentCheckBox = QtWidgets.QCheckBox(self.optionGroupBox)
        self.privateTorrentCheckBox.setObjectName("privateTorrentCheckBox")
        self.gridLayout_2.addWidget(self.privateTorrentCheckBox, 6, 0, 1, 2)
        self.commentLabel = QtWidgets.QLabel(self.optionGroupBox)
        self.commentLabel.setObjectName("commentLabel")
        self.gridLayout_2.addWidget(self.commentLabel, 4, 0, 1, 1)
        self.commentEdit = QtWidgets.QLineEdit(self.optionGroupBox)
        self.commentEdit.setObjectName("commentEdit")
        self.gridLayout_2.addWidget(self.commentEdit, 5, 0, 1, 2)
        self.verticalLayout.addWidget(self.optionGroupBox)
        self.progressBar = QtWidgets.QProgressBar(self.centralwidget)
        self.progressBar.setProperty("value", 24)
        self.progressBar.setObjectName("progressBar")
        self.verticalLayout.addWidget(self.progressBar)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.createButton = QtWidgets.QPushButton(self.centralwidget)
        self.createButton.setObjectName("createButton")
        self.horizontalLayout.addWidget(self.createButton)
        self.cancelButton = QtWidgets.QPushButton(self.centralwidget)
        self.cancelButton.setObjectName("cancelButton")
        self.horizontalLayout.addWidget(self.cancelButton)
        self.resetButton = QtWidgets.QPushButton(self.centralwidget)
        self.resetButton.setObjectName("resetButton")
        self.horizontalLayout.addWidget(self.resetButton)
        self.verticalLayout.addLayout(self.horizontalLayout)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtWidgets.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 496, 21))
        self.menubar.setObjectName("menubar")
        self.menuFile = QtWidgets.QMenu(self.menubar)
        self.menuFile.setObjectName("menuFile")
        self.menuHelp = QtWidgets.QMenu(self.menubar)
        self.menuHelp.setObjectName("menuHelp")
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtWidgets.QStatusBar(MainWindow)
        self.statusbar.setObjectName("statusbar")
        MainWindow.setStatusBar(self.statusbar)
        self.actionImportTrackers = QtWidgets.QAction(MainWindow)
        self.actionImportTrackers.setObjectName("actionImportTrackers")
        self.actionExportTrackers = QtWidgets.QAction(MainWindow)
        self.actionExportTrackers.setObjectName("actionExportTrackers")
        self.actionAbout = QtWidgets.QAction(MainWindow)
        self.actionAbout.setObjectName("actionAbout")
        self.actionQuit = QtWidgets.QAction(MainWindow)
        self.actionQuit.setObjectName("actionQuit")
        self.menuFile.addAction(self.actionImportTrackers)
        self.menuFile.addAction(self.actionExportTrackers)
        self.menuFile.addSeparator()
        self.menuFile.addAction(self.actionQuit)
        self.menuHelp.addAction(self.actionAbout)
        self.menubar.addAction(self.menuFile.menuAction())
        self.menubar.addAction(self.menuHelp.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        _translate = QtCore.QCoreApplication.translate
        MainWindow.setWindowTitle(_translate("MainWindow", "MainWindow"))
        self.inputGroupBox.setTitle(_translate("MainWindow", "Input"))
        self.fileRadioButton.setText(_translate("MainWindow", "File"))
        self.directoryRadioButton.setText(_translate("MainWindow", "Directory"))
        self.browseButton.setText(_translate("MainWindow", "Browse..."))
        self.batchModeCheckBox.setToolTip(_translate("MainWindow", "<html><head/><body><p>If enabled, a torrent will be created for each directory and file one level below the input directory. The piece size for each torrent will be determined automatically.</p></body></html>"))
        self.batchModeCheckBox.setText(_translate("MainWindow", "Batch mode"))
        self.seedingGroupBox.setTitle(_translate("MainWindow", "Seeding"))
        self.trackerLabel.setText(_translate("MainWindow", "Tracker URLs (one per line)"))
        self.webSeedLabel.setText(_translate("MainWindow", "HTTP/FTP seeds (one per line)"))
        self.optionGroupBox.setTitle(_translate("MainWindow", "Torrent options"))
        self.pieceCountLabel.setText(_translate("MainWindow", "# pieces"))
        self.md5CheckBox.setToolTip(_translate("MainWindow", "<html><head/><body><p>This is not used by BitTorrent at all, but it is included by some programs for greater compatibility.</p></body></html>"))
        self.md5CheckBox.setText(_translate("MainWindow", "Compute MD5 hashes"))
        self.pieceSizeLabel.setText(_translate("MainWindow", "Piece size"))
        self.privateTorrentCheckBox.setToolTip(_translate("MainWindow", "<html><head/><body><p>If enabled, clients will not use DHT or Peer Exchange to discover peers or transfer data. Make sure to enable this option for private trackers.</p></body></html>"))
        self.privateTorrentCheckBox.setText(_translate("MainWindow", "Private torrent"))
        self.commentLabel.setText(_translate("MainWindow", "Comment"))
        self.createButton.setText(_translate("MainWindow", "Create..."))
        self.cancelButton.setText(_translate("MainWindow", "Cancel"))
        self.resetButton.setText(_translate("MainWindow", "Reset"))
        self.menuFile.setTitle(_translate("MainWindow", "File"))
        self.menuHelp.setTitle(_translate("MainWindow", "Help"))
        self.actionImportTrackers.setText(_translate("MainWindow", "Import trackers..."))
        self.actionImportTrackers.setShortcut(_translate("MainWindow", "Ctrl+O"))
        self.actionExportTrackers.setText(_translate("MainWindow", "Export trackers..."))
        self.actionExportTrackers.setShortcut(_translate("MainWindow", "Ctrl+S"))
        self.actionAbout.setText(_translate("MainWindow", "About"))
        self.actionQuit.setText(_translate("MainWindow", "Quit"))
        self.actionQuit.setShortcut(_translate("MainWindow", "Ctrl+Q"))


if __name__ == "__main__":
    import sys
    app = QtWidgets.QApplication(sys.argv)
    MainWindow = QtWidgets.QMainWindow()
    ui = Ui_MainWindow()
    ui.setupUi(MainWindow)
    MainWindow.show()
    sys.exit(app.exec_())

